#import stuffs
from gsheets import Sheets
import pandas as pd
import sys
import matplotlib
matplotlib.use('Agg')
import matplotlib.pyplot as plt
from PIL import Image 

sheets = Sheets.from_files('client_secrets.json', 'storage.json')
sheets  #doctest: +ELLIPSIS


#specify sheet via url
url = 'https://docs.google.com/spreadsheets/d/1SrZfvr2ee54r7HR1jGtAE9zHIj_Y-UzK9ok8bdwkpqc/edit?usp=sharing'
s = sheets.get(url)
#load into csv
s.sheets[0].to_csv('detail.csv', encoding='utf-8', dialect='excel')


df = pd.read_csv('detail.csv')
#print("Enter the column for x-axis")
#x = input()
#print("Enter the column for y-axis")
#y = input()
fig = plt.figure()
x = sys.argv[1]
y = sys.argv[2]
#plot using the columns
plt.scatter(df[str(sys.argv[1])],df[str(sys.argv[2])])
plt.xlabel(x)
plt.ylabel(y)
#save images
fig.savefig('test.png')
# Read image 
img = Image.open('test.png') 
# Output Images 
img.show() 




from setuptools import setup, find_packages


classifiers = {
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
}

setup(
    name="plotursheet",
    version="0.0.3",
    description="A Python package to plot data from google sheets",
    long_description='\n\n'.join([
        open('README.txt').read()
        ]),
    long_description_content_type='text/markdown',
    url="https://github.com/fat-a-lity/plotursheet",
    author="Varun Chandran",
    author_email="varunjay7@gmail.com",
    license="MIT",
    classifiers= classifiers,
    keywords='gsheets',
    packages=find_packages(),
    include_package_data=True,
    install_requires=["gsheets","pandas","numpy","matplotlib.com"]
)